<?php

declare(strict_types=1);

namespace Drupal\nuxtify_menu_icons\Form;

use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Markup;
use GuzzleHttp\ClientInterface;
use Iconify\IconsJSON\Finder;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * A form where a user can pick an icon.
 */
class NuxtifyMenuIconsIconPickerForm extends FormBase {

  /**
   * The Drupal cache backend service.
   */
  protected CacheBackendInterface $cache;

  /**
   * The Guzzle HTTP client service.
   */
  protected ClientInterface $httpClient;

  /**
   * {@inheritdoc}
   */
  public function __construct(
    CacheBackendInterface $cache,
    ClientInterface $http_client,
  ) {
    $this->cache = $cache;
    $this->httpClient = $http_client;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('cache.default'),
      $container->get('http_client'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'nuxtify_menu_icons_icon_picker_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = $form + [
      '#attached' => [
        'library' => [
          'nuxtify_menu_icons/iconify',
          'nuxtify_menu_icons/icon-picker',
        ],
      ],
    ];

    $form['search'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Search'),
      '#description' => $this->t('Search for an icon by name.'),
      '#wrapper_attributes' => [
        'class' => [
          'nuxtify-menu-icons--search',
        ],
      ],
    ];

    $icons = $this->getIcons('mdi');

    // @todo Fix the rendering performance of this form by
    // lazy loading the icons.
    foreach ($icons as $name) {
      $form['icons'][$name] = [
        '#markup' => Markup::create('<span class="iconify" data-icon="' . $name . '"></span>'),
        '#prefix' => Markup::create('<div>'),
        '#suffix' => Markup::create('<p>' . $name . '</p></div>'),
      ];
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
  }

  /**
   * Get the icons from the Iconify collection.
   */
  private function getIcons(string $collection) {
    $json_path = Finder::locate($collection);
    $json = file_get_contents($json_path);
    $icon_data = json_decode($json, TRUE);

    foreach ($icon_data['icons'] as $name => $icon) {
      $icons[] = $collection . ':' . $name;
    }

    return $icons;
  }

}
