<?php

declare(strict_types=1);

namespace Drupal\nuxtify_menu_icons\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Markup;
use Drupal\Core\Url;

/**
 * Plugin implementation of the 'icon_picker' widget.
 *
 * @FieldWidget(
 *   id = "nuxtify_menu_icons_icon_picker",
 *   label = @Translation("Icon Picker"),
 *   field_types = {
 *     "nuxtify_menu_icons_icon",
 *   }
 * )
 */
class IconPicker extends WidgetBase {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state): array {
    $element['#attached'] = [
      'library' => [
        'nuxtify_menu_icons/iconify',
        'nuxtify_menu_icons/icon-preview',
      ],
    ];

    $element['value'] = $element + [
      '#type' => 'textfield',
      '#default_value' => $items[$delta]->value ?? NULL,
      '#wrapper_attributes' => [
        'style' => 'display: none;',
      ],
    ];

    $icon_value = $items[$delta]->value ?? NULL;
    $icon = $icon_value ?? '';
    $icon_text = $icon_value ?? $this->t('No icon selected');

    $element['title'] = [
      '#type' => 'html_tag',
      '#tag' => 'label',
      '#value' => $this->t('Menu icon'),
      '#attributes' => [
        'class' => [
          'form-item__label',
        ],
      ],
    ];

    $element['preview'] = [
      '#markup' => Markup::create('<span class="iconify" data-icon="' . $icon . '"></span>' . $icon_text),
      '#prefix' => '<div class="nuxtify-menu-icons--icon-preview">',
      '#suffix' => '</div>',
    ];

    $element['picker'] = [
      '#type' => 'link',
      '#title' => $this->t('Pick an icon'),
      '#url' => Url::fromRoute('nuxtify_menu_icons.icon_picker'),
      '#ajax' => [
        'dialogType' => 'modal',
        'dialog' => ['height' => 600, 'width' => 800],
      ],
      '#attributes' => [
        'class' => ['nuxtify-menu-icons--icon-picker'],
      ],
    ];

    return $element;
  }

}
